==> haskell-witherable-0.4.2-130-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-witherable.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 witherable
version:              0.4.2
visibility:           public
id:                   witherable-0.4.2-DMPolFE7DqrDZ3vcvJEHQ2
key:                  witherable-0.4.2-DMPolFE7DqrDZ3vcvJEHQ2
license:              BSD-3-Clause
copyright:            Copyright (c) 2014 Fumiaki Kinoshita
maintainer:           Fumiaki Kinoshita <fumiexcel@gmail.com>
author:               Fumiaki Kinoshita
homepage:             https://github.com/fumieval/witherable
synopsis:             filterable traversable
description:
    A stronger variant of `traverse` which can remove elements and generalised mapMaybe, catMaybes, filter

category:             Data
abi:                  94b76fcf53941e37b22ca64e1ca4f691
exposed:              True
exposed-modules:      Data.Witherable Witherable
import-dirs:          /usr/lib/ghc-9.4.8/site-local/witherable-0.4.2
library-dirs:         /usr/lib/ghc-9.4.8/site-local/witherable-0.4.2
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/witherable-0.4.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-witherable
hs-libraries:         HSwitherable-0.4.2-DMPolFE7DqrDZ3vcvJEHQ2
depends:
    base-4.17.2.1 base-orphans-0.8.8.2-FI78zSWUGveEpCXYJ99Iav
    containers-0.6.7 hashable-1.4.4.0-AtkYwZfsO44KEb9h1CQ6ig
    indexed-traversable-0.1.4-7ph7dHdACfa9uO4tGpH9sc
    indexed-traversable-instances-0.1.2-Fp99G2g9qpH8JaWBa82DUg
    transformers-0.5.6.2
    unordered-containers-0.2.20-6lPJVAOvNaZ2RxvZwsH66g
    vector-0.13.1.0-DP5vqiFKsIZ25TyoutQAjD

haddock-interfaces:   /usr/share/doc/haskell-witherable/html/witherable.haddock
haddock-html:         /usr/share/doc/haskell-witherable/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-witherable-0.4.2-133-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-witherable.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 witherable
version:              0.4.2
visibility:           public
id:                   witherable-0.4.2-3g66vrMyBIU1zB2bFlBsKh
key:                  witherable-0.4.2-3g66vrMyBIU1zB2bFlBsKh
license:              BSD-3-Clause
copyright:            Copyright (c) 2014 Fumiaki Kinoshita
maintainer:           Fumiaki Kinoshita <fumiexcel@gmail.com>
author:               Fumiaki Kinoshita
homepage:             https://github.com/fumieval/witherable
synopsis:             filterable traversable
description:
    A stronger variant of `traverse` which can remove elements and generalised mapMaybe, catMaybes, filter

category:             Data
abi:                  b2f1676b3cd4ea8bb666b3c33faf5f10
exposed:              True
exposed-modules:      Data.Witherable Witherable
import-dirs:          /usr/lib/ghc-9.4.8/site-local/witherable-0.4.2
library-dirs:         /usr/lib/ghc-9.4.8/site-local/witherable-0.4.2
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/witherable-0.4.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-witherable
hs-libraries:         HSwitherable-0.4.2-3g66vrMyBIU1zB2bFlBsKh
depends:
    base-4.17.2.1 base-orphans-0.8.8.2-FEffy3DtXbz5YHgxbB6Zcu
    containers-0.6.7 hashable-1.4.4.0-nWtkxUvx9i9tMRJKCZgnw
    indexed-traversable-0.1.4-EiyQIsHWfilLwzPb8OdnEq
    indexed-traversable-instances-0.1.2-DDnguEh6N2Y8s6YyLmZIiH
    transformers-0.5.6.2
    unordered-containers-0.2.20-FzN23deFW3GkzXU7VwkDd
    vector-0.13.1.0-D9au4GPCsbT1DKgXASrr5O

haddock-interfaces:   /usr/share/doc/haskell-witherable/html/witherable.haddock
haddock-html:         /usr/share/doc/haskell-witherable/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
